@@ -9,7 +9,7 @@ min_args = 1
 
 
 def run(args):
-    command = ' '.join(args)
+    command = " ".join(args)
     for directory in git.get_directories():
         message.bright("* Running command in %s" % directory)
-        os.system("cd %s; %s" % (directory, command))
\ No newline at end of file
+        os.system("cd %s; %s" % (directory, command))
