@@ -1,13 +1,13 @@
 import os
 from workspace import env, git, message, cmake
 
-name = 'pull'
+name = "pull"
 help = """Pull all the repositories"""
 usage = ""
 min_args = 0
 
+
 def run(args):
-  git.global_command('git pull')
-  git.scan_all_dependencies()
-  cmake.generate()
-  
\ No newline at end of file
+    git.global_command("git pull")
+    git.scan_all_dependencies()
+    cmake.generate()
